==> dendria-node-0.0.2.tgz: package/index.js <==
import fs from 'fs'
import path from 'path'
import vipfs from 'vipfs';
//import stringify from 'json-stringify-deterministic';
import DendriaCore from 'dendria-core';
import { packToFs } from 'ipfs-car/pack/fs'
import { CarIndexedReader } from '@ipld/car'
//import { Blob } from 'nft.storage'
export default class DendriaNode extends DendriaCore {
  async publishFS (p) {
    let stat = await fs.promises.lstat(p)
    if (stat.isDirectory()) {
      let calccid = await this.cidFS(p)
      const { root } = await packToFs({
        input: p,
        output: `${calccid}.car`,
        wrapWithDirectory: false
      })
      const expectedCid = root.toString()

      // Create the car reader
      const carReader = await CarIndexedReader.fromFile(`${expectedCid}.car`)
      const cid = await this.storage.storeCar(carReader)

      // remove the car file
      await fs.promises.rm(`${expectedCid}.car`)
      return cid

    } else if (stat.isFile()) {
      const data = await fs.promises.readFile(p)
      const blob = await this.nuron.nuronfs.serialize(data)
      //const cid = await this.storage.storeBlob(new Blob([data]))
      const cid = await this.storage.storeBlob(blob)
      return cid
    }
  }
  async cidFS(p) {
    let stat = await fs.promises.lstat(p)
    if (stat.isDirectory()) {
      const cid = await vipfs.directory(p)
      return cid
    } else if (stat.isFile()) {
      const data = await fs.promises.readFile(p)
      const cid = await vipfs.buffer(data)
      return cid
    } else {
      throw new Error("not a file and not a directory")
    }
  }
  async writeFS(p, data, options) {
    let blob = await this.nuron.nuronfs.serialize(data, options)
    let buf = await blob.arrayBuffer()
    console.log("buf", buf)
    await fs.promises.mkdir(path.dirname(p)).catch((e) => { })
    await fs.promises.writeFile(p, Buffer.from(buf))
    let cid = await this.cidFS(p)
    return cid
    
    //let type = data.constructor.name;
    //let buffer;
    //if (type === "Buffer") {
    //  buffer = data
    //} else if (typeof data === "string") {
    //  buffer = Buffer.from(data)
    //} else if (typeof data === "object") {
    //  buffer = Buffer.from(stringify(data))
    //} else {
    //  throw new Error("must be a buffer, a string, or an object")
    //}
    //await fs.promises.mkdir(path.dirname(p)).catch((e) => { })
    //await fs.promises.writeFile(p, buffer)
    //let cid = await this.cidFS(p)
    //return cid
  }
}

==> dendria-node-0.0.4.tgz: package/index.js <==
import fs from 'fs'
import path from 'path'
import vipfs from 'vipfs';
//import stringify from 'json-stringify-deterministic';
import DendriaCore from 'dendria-core';
import { packToFs } from 'ipfs-car/pack/fs'
import { CarIndexedReader } from '@ipld/car'
//import { Blob } from 'nft.storage'
export default class DendriaNode extends DendriaCore {
  async publishFS (p) {
    let stat = await fs.promises.lstat(p)
    if (stat.isDirectory()) {
      let calccid = await this.cidFS(p)
      const { root } = await packToFs({
        input: p,
        output: `${calccid}.car`,
        wrapWithDirectory: false
      })
      const expectedCid = root.toString()

      // Create the car reader
      const carReader = await CarIndexedReader.fromFile(`${expectedCid}.car`)
      const cid = await this.storage.storeCar(carReader)

      // remove the car file
      await fs.promises.rm(`${expectedCid}.car`)
      return cid

    } else if (stat.isFile()) {
      const data = await fs.promises.readFile(p)
      const blob = await this.nuron.nuronium.serialize(data)
      //const cid = await this.storage.storeBlob(new Blob([data]))
      const cid = await this.storage.storeBlob(blob)
      return cid
    }
  }
  async cidFS(p) {
    let stat = await fs.promises.lstat(p)
    if (stat.isDirectory()) {
      const cid = await vipfs.directory(p)
      return cid
    } else if (stat.isFile()) {
      const data = await fs.promises.readFile(p)
      const cid = await vipfs.buffer(data)
      return cid
    } else {
      throw new Error("not a file and not a directory")
    }
  }
  async writeFS(p, data, options) {
    let blob = await this.nuron.nuronium.serialize(data, options)
    let buf = await blob.arrayBuffer()
    console.log("buf", buf)
    await fs.promises.mkdir(path.dirname(p)).catch((e) => { })
    await fs.promises.writeFile(p, Buffer.from(buf))
    let cid = await this.cidFS(p)
    return cid
    
    //let type = data.constructor.name;
    //let buffer;
    //if (type === "Buffer") {
    //  buffer = data
    //} else if (typeof data === "string") {
    //  buffer = Buffer.from(data)
    //} else if (typeof data === "object") {
    //  buffer = Buffer.from(stringify(data))
    //} else {
    //  throw new Error("must be a buffer, a string, or an object")
    //}
    //await fs.promises.mkdir(path.dirname(p)).catch((e) => { })
    //await fs.promises.writeFile(p, buffer)
    //let cid = await this.cidFS(p)
    //return cid
  }
}
